@@ -26,6 +26,7 @@
 
 #include <Lum/Def/Menu.h>
 
+#include <Lum/Application.h>
 #include <Lum/Button.h>
 #include <Lum/Combo.h>
 #include <Lum/Dialog.h>
@@ -37,7 +38,7 @@
 
 #include <Lum/Model/Action.h>
 
-#include <Lum/OS/Main.h>
+#include <Lum/Manager/Behaviour.h>
 
 #include "Configuration.h"
 #include "DiceSetList.h"
@@ -84,14 +85,16 @@ public:
     setsModel->SetEmptyText(L"(No dice sets defined)");
 
     Lum::Def::OneOfMany setChoiceDef(Lum::Def::Desc(L"Dice Set"),
-                                     currentSet,setsModel);
+                                     currentSet,
+                                     setsModel,
+                                     new DiceSetModelPainter());
 
     Lum::Object         *setChoice;
     Lum::Panel          *vert;
 
     vert=Lum::VPanel::Create(true,true);
 
-    setChoice=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(setChoiceDef);
+    setChoice=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(setChoiceDef);
     setChoice->SetFlex(true,false);
     setChoice->SetMinWidth(Lum::Base::Size::stdCharWidth,20);
 
@@ -268,30 +271,22 @@ public:
   }
 };
 
-class Main : public Lum::OS::MainDialog<MainDialog>
+class Main : public Lum::GUIApplication<MainDialog>
 {
 public:
-  Main()
+  bool Initialize()
   {
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
-    info.SetDescription(L"Role the dice...");
+    info.SetDescription(L"Roll the dice...");
     info.SetAuthor(L"Tim Teulings");
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2008, Tim Teulings");
     info.SetLicense(L"GNU Public License");
 
     srand(time(NULL));
-  }
-
-  bool Prepare()
-  {
-    return Lum::OS::MainDialog<MainDialog>::Prepare();
-  }
-
-  void Cleanup()
-  {
-    Lum::OS::MainDialog<MainDialog>::Cleanup();
+    
+    return Lum::GUIApplication<MainDialog>::Initialize();
   }
 };
 
